==> plugin-api-1.3.2-sources.jar: com/xebialabs/deployit/ci/HostAccessMethod.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci;

/**
 * The mechanism used to access a host.
 */
public enum HostAccessMethod {

	/**
	 * No access.
	 */
	NONE,

	/**
	 * Direct OS access.
	 */
	LOCAL,

	/**
	 * SSH access w/ file access using SFTP.
	 */
	SSH_SFTP,

	/**
	 * SSH access w/ file access using SCP.
	 */
	SSH_SCP,

	/**
	 * SSH access w/ SUDO and file access using SCP.
	 */
	SSH_SUDO,

	/**
	 * File access using CIFS, command execution using telnet.
	 */
	CIFS_TELNET

}

==> plugin-api-1.4-sources.jar: com/xebialabs/deployit/ci/HostAccessMethod.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci;

/**
 * The mechanism used to access a host.
 */
public enum HostAccessMethod {

	/**
	 * No access.
	 */
	NONE,

	/**
	 * Direct OS access.
	 */
	LOCAL,

	/**
	 * File access through SFTP, command execution through SSH.
	 */
	SSH_SFTP,

	/**
	 * File access through SCP, command execution through SSH.
	 */
	SSH_SCP,

	/**
	 * File access through SCP, command execution through SSH with SUDO configured with NOPASSWD.
	 */
	SSH_SUDO,

	/**
	 * File access through SCP, command execution through SSH with interactive SUDO.
	 */
	SSH_INTERACTIVE_SUDO,

	/**
	 * File access through CIFS, command execution through Telnet.
	 */
	CIFS_TELNET

}
